@@ -17,7 +17,7 @@ class Decken800GUI(ui.DeckenGUI):
 			self.window.connect('destroy', gtk.main_quit)
 			
 		# chamar init da superclasse
-		super(B, self).__init__()
+		super(Decken800GUI, self).__init__()
 		
 		# reparent the vbox1 from glade to self.window
 		self.vbox1 = self.get_widget('vbox1')
